@@ -171,6 +171,8 @@ def get_node(awsclient, node, snapshot_source, snapshot):
                         put_in_currentdata('errors', data)
                         logger.info("Describe function does not exist: %s", str(function_to_call))
                         db_record['error'] = "Describe function does not exist: %s" % str(function_to_call)
+                else:
+                    logger.warn('No snapshot data found for resource %s' % queryval)
             except Exception as ex:
                 logger.warning('Describe function exception: %s', ex)
                 db_record['error'] = 'Describe function exception: %s' % ex
@@ -207,6 +209,8 @@ def get_node(awsclient, node, snapshot_source, snapshot):
                 logger.info('Invalid function exception: %s', str(function_to_call))
                 db_record['error'] = 'Invalid function exception: %s' % str(function_to_call)
             set_input_data_in_json(data, json_to_put, client_str, resourceid, arn_str, each_method_str)
+        if not json_to_put:
+            logger.warn('No snapshot data found for resource %s' % arn_str)
         db_record['json'] = json_to_put
         checksum = get_checksum(json_to_put)
         if checksum:
